@@ -3,6 +3,7 @@ from p2p_python.user import UserHeader, User
 from logging import getLogger
 from typing import Dict, Optional
 from time import time
+import asyncio
 import os
 
 # For AES
@@ -11,32 +12,44 @@ from Cryptodome.Util.Padding import pad, unpad
 from Cryptodome import Random
 from base64 import b64encode, b64decode
 
+loop = asyncio.get_event_loop()
 log = getLogger(__name__)
 
 
-class EventIgnition:
+class EventIgnition(object):
 
     def __init__(self):
         self.event = dict()
 
-    def addevent(self, cmd, f, post_f=None):
-        self.event[cmd] = (f, post_f)
+    def setup_events_from_class(self, klass):
+        for cmd, fnc in klass.__dict__.items():
+            if cmd.startswith('_'):
+                continue
+            if isinstance(fnc, staticmethod):
+                fnc = fnc.__func__
+            self.add_event(cmd, fnc)
 
-    def removevent(self, cmd):
+    def add_event(self, cmd, fnc):
+        assert fnc.__code__.co_argcount == 2
+        if cmd in self.event:
+            raise Exception('already registered cmd')
+        self.event[cmd] = fnc
+        log.info(f"add DirectCmd event '{cmd}'")
+
+    def remove_event(self, cmd):
         if cmd in self.event:
             del self.event[cmd]
 
-    def __contains__(self, item):
-        return item in self.event
+    def have_event(self, cmd):
+        return cmd in self.event
 
-    def work(self, cmd, data):
+    async def ignition(self, user, cmd, data):
         if cmd in self.event:
-            f, post_f = self.event[cmd]
-            r = f(data)
-            if post_f:
-                return post_f(r)
+            fnc = self.event[cmd]
+            if asyncio.iscoroutinefunction(fnc):
+                return await fnc(user, data)
             else:
-                return r
+                return fnc(user, data)
         else:
             raise KeyError('Not found cmd "{}"'.format(cmd))
 
