@@ -2,6 +2,7 @@ from asyncio.streams import StreamReader, StreamWriter
 from logging import getLogger
 from time import time
 from typing import Dict
+from collections import deque
 import asyncio
 
 
@@ -58,37 +59,38 @@ class User(object):
         "_writer",  # (StreamWriter) TCP socket writer
         "host_port",  # ([str, int])  Interface used on our PC
         "aeskey",  # (str) Common key
-        "sock_type",  # (str) We are as server or client side
+        "direction",  # (str) We are as server or client side
         "neers",  # ({host_port: header})  Neer clients info
         "score",  # (int )User score
         "warn",  # (int) User warning score
-        "event",  # (Event) user event object used for PingPong
+        "create_time",  # (int) User object creation time
+        "process_time",  # list of time used for process
     )
 
-    def __init__(self, header, number, reader, writer, host_port, aeskey, sock_type):
+    def __init__(self, header, number, reader, writer, host_port, aeskey, direction):
         self.header: UserHeader = header
         self.number = number
         self._reader: StreamReader = reader
         self._writer: StreamWriter = writer
         self.host_port = host_port
         self.aeskey = aeskey
-        self.sock_type = sock_type
+        self.direction = direction
         self.neers: Dict[(str, int), UserHeader] = dict()
         # user experience
         self.score = 0
         self.warn = 0
-        self.event = asyncio.Event()
+        self.create_time = int(time())
+        self.process_time = deque(maxlen=10)
 
     def __repr__(self):
-        age = int(time()) - self.header.start_time
+        age = (int(time()) - self.header.start_time) // 60
+        passed = (int(time()) - self.create_time) // 60
         host_port = self.host_port[0] + ":" + str(self.header.p2p_port)
         if self.closed:
             status = 'close'
-        elif not self.event.is_set():
-            status = 'ping..'
         else:
             status = 'open'
-        return f"<User {self.header.name} {status} {age//60}m {host_port} {self.score}/{self.warn}>"
+        return f"<User {self.header.name} {status} {passed}/{age}m ({host_port}) {self.score}/{self.warn}>"
 
     def __del__(self):
         self.close()
@@ -110,13 +112,15 @@ class User(object):
 
     def getinfo(self):
         return {
-            'header': self.header.getinfo(),
-            'neers': {"{}:{}".format(*host_port): header.getinfo() for host_port, header in self.neers.items()},
             'number': self.number,
-            'host_port': self.get_host_port(),
-            'sock_type': self.sock_type,
+            'object': repr(self),
+            'header': self.header.getinfo(),
+            'neers': [stringify_host_port(*host_port) for host_port in self.neers.keys()],
+            'host_port': stringify_host_port(*self.get_host_port()),
+            'direction': self.direction,
             'score': self.score,
             'warn': self.warn,
+            'average_process_time': self.average_process_time(),
         }
 
     def get_host_port(self) -> tuple:
@@ -130,6 +134,21 @@ class User(object):
         for host_port, header in items:
             self.neers[tuple(host_port)] = UserHeader(**header)
 
+    def average_process_time(self):
+        if len(self.process_time) == 0:
+            return None
+        else:
+            return sum(self.process_time) / len(self.process_time)
+
+
+def stringify_host_port(*args):
+    if len(args) == 2:
+        return "{}:{}".format(args[0], args[1])
+    elif len(args) == 4:
+        return "[{}]:{}".format(args[0], args[1])
+    else:
+        return str(args)
+
 
 __all__ = [
     "UserHeader",
