@@ -29,11 +29,23 @@ def get_version():
     """get program version string"""
     if Debug.P_PRINT_EXCEPTION:
         return 'debug'
-    hear = os.path.dirname(os.path.abspath(__file__))
-    with open(os.path.join(hear, '__init__.py'), mode='r') as fp:
-        for word in fp.readlines():
-            if word.startswith('__version__'):
-                return word.replace('"', "'").split("'")[-2]
+
+    # read version from code
+    try:
+        from p2p_python import __version__
+        return __version__
+    except Exception:
+        pass
+
+    # read version from file
+    try:
+        hear = os.path.dirname(os.path.abspath(__file__))
+        with open(os.path.join(hear, '__init__.py'), mode='r') as fp:
+            for word in fp.readlines():
+                if word.startswith('__version__'):
+                    return word.replace('"', "'").split("'")[-2]
+    except Exception:
+        pass
     return 'unknown'
 
 
@@ -87,8 +99,9 @@ async def is_reachable(host, port):
     """check a port is opened, finish in 2s"""
     future = loop.run_in_executor(
         None, socket.getaddrinfo, host, port, socket.AF_UNSPEC, socket.SOCK_STREAM)
-    await asyncio.wait_for(future, 10.0)
-    if future.cancelled():
+    try:
+        await asyncio.wait_for(future, 10.0)
+    except socket.gaierror:
         return False
     for af, socktype, proto, canonname, host_port in future.result():
         try:
